// src/index.ts
function getHighlightAPI() {
  if (globalThis.highlight === void 0) {
    throw new Error(
      "Your web app must be running in the Highlight app to use this module. Please see https://docs.highlight.ing for more details."
    );
  }
  return globalThis.highlight;
}
function awaitNextTextPrediction(id) {
  const api2 = getHighlightAPI();
  return new Promise((resolve) => {
    const createListener = () => {
      api2.once("onTextPredictionUpdate", (message) => {
        if (message.id !== id) {
          createListener();
          return;
        }
        resolve(message.text);
      });
    };
    createListener();
  });
}
var api = {
  user: {
    getFacts: () => getHighlightAPI().user.getFacts(),
    getAudio: (longAudio) => getHighlightAPI().user.getAudio(longAudio),
    setAsrRealtime: (isActive) => getHighlightAPI().user.setAsrRealtime(isActive),
    getMicActivity: (lastNumMs) => getHighlightAPI().user.getMicActivity(lastNumMs),
    getScreenshot: () => getHighlightAPI().user.getScreenshot(),
    getEmail: () => getHighlightAPI().user.getEmail()
  },
  auth: {
    signIn: () => getHighlightAPI().auth.signIn()
  },
  inference: {
    getTextPrediction: async function* (messages) {
      const api2 = getHighlightAPI();
      const id = await api2.internal.getTextPrediction(messages);
      let done = false;
      const onTextPredictionDoneListener = (message) => {
        if (message.id !== id) {
          return;
        }
        done = true;
      };
      api2.addEventListener(
        "onTextPredictionDone",
        onTextPredictionDoneListener
      );
      while (!done) {
        yield await awaitNextTextPrediction(id);
      }
      api2.removeEventListener(
        "onTextPredictionDone",
        onTextPredictionDoneListener
      );
    }
  },
  addEventListener: (event, listener) => {
    getHighlightAPI().addEventListener(event, listener);
  },
  removeEventListener: (event, listener) => {
    getHighlightAPI().removeEventListener(event, listener);
  },
  once: (event, listener) => {
    getHighlightAPI().once(event, listener);
  }
};
var src_default = api;
export {
  src_default as default
};
//# sourceMappingURL=index.js.map